/*****************************************************************************
 * Eliot
 * Copyright (C) 2007-2010 Olivier Teulière
 * Authors: Olivier Teulière <ipkiss @@ gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *****************************************************************************/

#include "game_exception.h"

using namespace std;


GameException::GameException(const string &iMessage)
    : BaseException(iMessage)
{
}


EndGameException::EndGameException(const string &iMessage)
    : GameException(iMessage)
{
}


LoadGameException::LoadGameException(const string &iMessage)
    : GameException(iMessage)
{
}


SaveGameException::SaveGameException(const string &iMessage)
    : GameException(iMessage)
{
}

